All Classes and Interfaces

Class
Description
The ApplicationContext extends a Context for out of the box application requirements such as lifecycle support (as if the LifecycleComponent alongside the LifecycleMachine).
The ApplicationReactor enables harnessing the CliApplicationProperties alongside the CliApplicationProperties profile support (as of ProfileProperties.getRuntimeProfiles()) by automatically placing an accordingly configured CliApplicationProperties instance into the container and enabling it for injection.
The ApplicationReactor.ProfilesMode determines how to handle implicit profiles information as provided by the CliApplicationProperties instance (implicitly added as Dependency by the ApplicationReactor).