Package org.refcodes.decoupling.ext.application


package org.refcodes.decoupling.ext.application
This artifact extends the refcodes-decoupling artifact with out of the box runtime functionality such as properties management (alongside profiles support) and CLI) support by integrating the refcodes-properties-ext-application artifact.

Please refer to the refcodes-decoupling: Breaking up dependencies between components documentation for an up-to-date and detailed description on the usage of this artifact.