Uses of Package
org.refcodes.decoupling.ext.application
-
Classes in org.refcodes.decoupling.ext.application used by org.refcodes.decoupling.ext.applicationClassDescriptionThe
ApplicationContextextends aContextfor out of the box application requirements such as lifecycle support (as if theLifecycleComponentalongside theLifecycleMachine).TheApplicationReactor.ProfilesModedetermines how to handle implicit profiles information as provided by theApplicationPropertiesinstance (implicitly added asDependencyby theApplicationReactor).