All Classes and Interfaces
Class
Description
The
ApplicationContext extends a Context for out of the box
application requirements such as lifecycle support (as if the
LifecycleComponent alongside the LifecycleMachine).The
ApplicationReactor enables harnessing the
ApplicationProperties alongside the ApplicationProperties
profile support (as of ProfileProperties.getRuntimeProfiles()) by
automatically placing an accordingly configured ApplicationProperties
instance into the container and enabling it for injection.The
ApplicationReactor.ProfilesMode determines how to handle implicit profiles
information as provided by the ApplicationProperties instance
(implicitly added as Dependency by the
ApplicationReactor).