Package org.refcodes.decoupling.ext.application
package org.refcodes.decoupling.ext.application
This artifact extends the
refcodes-decoupling
artifact with out of the box runtime functionality such as properties
management (alongside profiles support) and
CLI)
support by integrating the refcodes-properties-ext-application
artifact.
Please refer to the refcodes-decoupling: Breaking up dependencies between components documentation for an up-to-date and detailed description on the usage of this artifact.
-
ClassDescriptionThe
ApplicationContextextends aContextfor out of the box application requirements such as lifecycle support (as if theLifecycleComponentalongside theLifecycleMachine).TheApplicationReactorenables harnessing theCliApplicationPropertiesalongside theCliApplicationPropertiesprofile support (as ofProfileProperties.getRuntimeProfiles()) by automatically placing an accordingly configuredCliApplicationPropertiesinstance into the container and enabling it for injection.TheApplicationReactor.ProfilesModedetermines how to handle implicit profiles information as provided by theCliApplicationPropertiesinstance (implicitly added asDependencyby theApplicationReactor).